@@ -72,7 +72,7 @@ static const GtkActionEntry menu_entries[] =
 	{ "Preferences", GTK_STOCK_PREFERENCES, NULL, NULL,
 	  N_("Configure the application"), G_CALLBACK (cb_edit_preferences) },
 
-	{ "Refresh", NULL, N_("_Refresh"), "<control>R",
+	{ "Refresh", GTK_STOCK_REFRESH, N_("_Refresh"), "<control>R",
 	  N_("Refresh the process list"), G_CALLBACK(cb_user_refresh) },
 
 	{ "MemoryMaps", NULL, N_("_Memory Maps"), "<control>M",
@@ -553,7 +553,7 @@ menu_item_select_cb (GtkMenuItem *proxy,
 	GtkAction *action;
 	char *message;
 
-	action = gtk_widget_get_action(GTK_WIDGET(proxy));
+	action = gtk_activatable_get_related_action (GTK_ACTIVATABLE(proxy));
 	g_assert(action);
 
 	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
