@@ -24,6 +24,7 @@
 #include <string.h>
 #include <math.h>
 #include <glib/gi18n.h>
+#include <glib/gprintf.h>
 #include <glibtop.h>
 #include <glibtop/loadavg.h>
 #include <glibtop/proclist.h>
@@ -426,20 +427,23 @@ ProcInfo::~ProcInfo()
 
 static void
 get_process_name (ProcInfo *info,
-		  const gchar *cmd, const gchar *args)
+		  const gchar *cmd, const GStrv args)
 {
-	if (args && *args)
-	{
-		char* basename;
-		basename = g_path_get_basename (args);
+	if (args) {
+		// look for /usr/bin/very_long_name
+		// and also /usr/bin/interpreter /usr/.../very_long_name
+		// which may have use prctl to alter 'cmd' name
+		for (int i = 0; i != 2 && args[i]; ++i) {
+			char* basename;
+			basename = g_path_get_basename(args[i]);
 
-		if(g_str_has_prefix (basename, cmd))
-		{
-			info->name = basename;
-			return;
+			if (g_str_has_prefix(basename, cmd)) {
+				info->name = basename;
+				return;
+			}
+
+			g_free(basename);
 		}
-
-		g_free (basename);
 	}
 
 	info->name = g_strdup (cmd);
@@ -462,16 +466,16 @@ ProcInfo::set_user(guint uid)
 	// procman_debug("User lookup for uid %u: %s", uid, (p.second ? "MISS" : "HIT"));
 
 	if (p.second) {
-		char* username;
 		struct passwd* pwd;
 		pwd = getpwuid(uid);
 
 		if (pwd && pwd->pw_name)
-			username = g_strdup(pwd->pw_name);
-		else
-			username = g_strdup_printf("%u", uid);
-
-		p.first->second = username;
+			p.first->second = pwd->pw_name;
+		else {
+			char username[16];
+			g_sprintf(username, "%u", uid);
+			p.first->second = username;
+		}
 	}
 
 	this->user = p.first->second;
@@ -483,21 +487,23 @@ static void get_process_memory_writable(ProcInfo *info)
 {
 	glibtop_proc_map buf;
 	glibtop_map_entry *maps;
-	unsigned i;
-
-	info->memwritable = 0;
 
 	maps = glibtop_get_proc_map(&buf, info->pid);
 
-	for (i = 0; i < buf.number; ++i) {
+	gulong memwritable = 0;
+	const unsigned number = buf.number;
+
+	for (unsigned i = 0; i < number; ++i) {
 #ifdef __linux__
-		info->memwritable += maps[i].private_dirty;
+		memwritable += maps[i].private_dirty;
 #else
 		if (maps[i].perm & GLIBTOP_MAP_PERM_WRITE)
-			info->memwritable += maps[i].size;
+			memwritable += maps[i].size;
 #endif
 	}
 
+	info->memwritable = memwritable;
+
 	g_free(maps);
 }
 
@@ -538,7 +544,7 @@ update_info_mutable_cols(ProcInfo *info)
 	using procman::tree_store_update;
 
 	tree_store_update(model, &info->node, COL_STATUS, info->status);
-	tree_store_update(model, &info->node, COL_USER, info->user);
+	tree_store_update(model, &info->node, COL_USER, info->user.c_str());
 	tree_store_update(model, &info->node, COL_VMSIZE, info->vmsize);
 	tree_store_update(model, &info->node, COL_MEMRES, info->memres);
 	tree_store_update(model, &info->node, COL_MEMWRITABLE, info->memwritable);
@@ -660,8 +666,8 @@ update_info (ProcData *procdata, ProcInfo *info)
 	info->pcpu = (proctime.rtime - info->cpu_time) * 100 / procdata->cpu_total_time;
 	info->pcpu = MIN(info->pcpu, 100);
 
-	if (procdata->config.solaris_mode)
-	  info->pcpu /= procdata->config.num_cpus;
+	if (not procdata->config.solaris_mode)
+	  info->pcpu *= procdata->config.num_cpus;
 
 	ProcInfo::cpu_times[info->pid] = info->cpu_time = proctime.rtime;
 	info->nice = procuid.nice;
@@ -688,7 +694,7 @@ ProcInfo::ProcInfo(pid_t pid)
 	arguments = glibtop_get_proc_argv (&procargs, pid, 0);
 
 	/* FIXME : wrong. name and arguments may change with exec* */
-	get_process_name (info, procstate.cmd, arguments[0]);
+	get_process_name (info, procstate.cmd, static_cast<const GStrv>(arguments));
 
 	std::string tooltip = make_string(g_strjoinv(" ", arguments));
 	if (tooltip.empty())
